API Reference
=============

This page documents the public API of the `bioio` package.

.. currentmodule:: bioio

Core Classes
------------

.. autosummary::
   :toctree: generated/
   :recursive:

   BioImage
   StandardMetadata
   Writer

Types and Aliases
-----------------

.. autosummary::
   :toctree: generated/
   :recursive:

   ArrayLike
   DimensionProperties
   MetaArrayLike
   Scale
   TimeInterval
   ImageLike
   PathLike
   PhysicalPixelSizes

Enums and Dimensions
--------------------

.. autosummary::
   :toctree: generated/
   :recursive:

   DimensionNames
   Dimensions

Utilities
---------

.. autosummary::
   :toctree: generated/
   :recursive:

   plugin_feasibility_report
